// 1.6.5 Arduino
// SHIP Server

#include <ESP8266WiFi.h>

const byte LED  = D0;

// Motor Driver

const byte pwmB = D1;
const byte Bin2 = D2;
const byte Bin1 = D3;

const byte pwmA = D6;
const byte Ain2 = D8;
const byte Ain1 = D4;

const byte detectLEFT  = D7;
const byte detectRIGHT = D5;

const byte CENTER = A0;

const byte toLEFT  = 0;
const byte toRIGHT = 1;

IPAddress apIP(10, 10, 10, 10);

const char *ssid = "SHIP";
const char *password = "xxxxxxxxxxxxxxxxxx";

WiFiServer server(80);

void setup() {

  Serial.begin(115200);

  WiFi.mode(WIFI_AP_STA);
  WiFi.softAPConfig(apIP, apIP, IPAddress(255, 255, 255, 0));   // subnet FF FF FF 00

  WiFi.softAP(ssid, password);

  IPAddress myIP = WiFi.softAPIP();

  server.begin();  // starts the server

  pinMode(Ain1, OUTPUT);
  pinMode(Ain2, OUTPUT);
  pinMode(Bin1, OUTPUT);
  pinMode(Bin2, OUTPUT);
  pinMode(pwmA, OUTPUT);
  pinMode(pwmB, OUTPUT);

  pinMode(LED, OUTPUT);
  digitalWrite(LED, LOW);

  pinMode(detectLEFT, INPUT_PULLUP);
  pinMode(detectRIGHT, INPUT_PULLUP);

  stop(); // Stop Motor

}

void loop () {
  WiFiClient client = server.available();
  if (client) {
    if (client.connected()) {
      digitalWrite(LED, HIGH);

      int volt = analogRead(A0);
      // 470 all is OFF
      // 327 on
      // 213 on

      String request = client.readStringUntil('\r');    // receives the message from the client
Serial.println(request);
Serial.println(digitalRead(detectRIGHT));
Serial.println(digitalRead(detectLEFT));

      if (request == "LL") {        
        if (digitalRead(detectLEFT) != 0) {
          moveA(toLEFT, 100);
          delay(500);
          stop();
        }
      }

      if (request == "RR") {
        if (digitalRead(detectRIGHT) != 0) {
          moveA(toRIGHT, 100);
          delay(500);
          stop();
        }
      }

      if (request == "AA") {
        if (volt > 300) {
          moveB(toLEFT, 100);
          delay(500);
          stop();
        }
      }

      if (request == "BB") {
        if (volt > 300) {
          moveB(toRIGHT, 100);
          delay(500);
          stop();
        }
      }

      client.println("OK\r");
      client.flush();
      digitalWrite(LED, LOW);
    }
    client.stop();                // tarminates the connection with the client
  }
}

/************************************/
/* MOVE(toLEFT|toRIGHT, 0-255)      */
/************************************/

void moveA(byte dir, byte speed) {

  if (dir == toLEFT) {
    digitalWrite(Ain1, LOW);
    digitalWrite(Ain2, HIGH);
    analogWrite(pwmA, speed);
  } else if (dir == toRIGHT) {
    digitalWrite(Ain1, HIGH);
    digitalWrite(Ain2, LOW);
    analogWrite(pwmA, speed);
  }

}

void moveB(byte dir, byte speed) {

  if (dir == toLEFT) {
    digitalWrite(Bin1, LOW);
    digitalWrite(Bin2, HIGH);
    analogWrite(pwmB, speed);
  } else if (dir == toRIGHT) {
    digitalWrite(Bin1, HIGH);
    digitalWrite(Bin2, LOW);
    analogWrite(pwmB, speed);
  }

}

void stop() {
  digitalWrite(Ain1, LOW);
  digitalWrite(Ain2, LOW);
  analogWrite(pwmA, 255);
  digitalWrite(Bin1, LOW);
  digitalWrite(Bin2, LOW);
  analogWrite(pwmB, 255);
}
